import { ElementRef, OnDestroy } from '@angular/core';
import { Subscription } from 'rxjs';
import { IDisplayDensityOptions, DisplayDensityBase } from '../../core/displayDensity';
import { IgxIconService } from '../../icon/public_api';
import { IgxGridToolbarActionsDirective } from './common';
import { GridServiceType, GridType } from '../common/grid.interface';
import * as i0 from "@angular/core";
/**
 * Provides a context-aware container component for UI operations for the grid components.
 *
 * @igxModule IgxGridToolbarModule
 *
 */
export declare class IgxGridToolbarComponent extends DisplayDensityBase implements OnDestroy {
    protected _displayDensityOptions: IDisplayDensityOptions;
    private api;
    private iconService;
    private element;
    /**
     * When enabled, shows the indeterminate progress bar.
     *
     * @remarks
     * By default this will be toggled, when the default exporter component is present
     * and an exporting is in progress.
     */
    showProgress: boolean;
    /**
     * Gets/sets the grid component for the toolbar component.
     *
     * @remarks
     * Usually you should not set this property in the context of the default grid/tree grid.
     * The only grids that demands this to be set are the hierarchical child grids. For additional
     * information check the toolbar topic.
     */
    get grid(): GridType;
    set grid(value: GridType);
    /** Returns the native DOM element of the toolbar component */
    get nativeElement(): HTMLElement;
    /**
     * @hidden
     * @internal
     */
    hasActions: IgxGridToolbarActionsDirective;
    /**
     * @hidden
     * @internal
     */
    defaultStyle: boolean;
    /**
     * @hidden
     * @internal
     */
    get cosyStyle(): boolean;
    /**
     * @hidden
     * @internal
     */
    get compactStyle(): boolean;
    protected _grid: GridType;
    protected sub: Subscription;
    constructor(_displayDensityOptions: IDisplayDensityOptions, api: GridServiceType, iconService: IgxIconService, element: ElementRef<HTMLElement>);
    /** @hidden @internal */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxGridToolbarComponent, [{ optional: true; }, null, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxGridToolbarComponent, "igx-grid-toolbar", never, { "showProgress": "showProgress"; "grid": "grid"; }, {}, ["hasActions"], ["[igxGridToolbarTitle],igx-grid-toolbar-title", "*", "[igxGridToolbarActions],igx-grid-toolbar-actions"], false>;
}
