import { TransactionService, Transaction, State, StateUpdateEvent } from './transaction';
import { EventEmitter } from '@angular/core';
import { IDataCloneStrategy } from '../../data-operations/data-clone-strategy';
export declare class IgxBaseTransactionService<T extends Transaction, S extends State> implements TransactionService<T, S> {
    /**
     * @inheritDoc
     */
    get cloneStrategy(): IDataCloneStrategy;
    set cloneStrategy(strategy: IDataCloneStrategy);
    /**
     * @inheritDoc
     */
    get canRedo(): boolean;
    /**
     * @inheritDoc
     */
    get canUndo(): boolean;
    /**
     * @inheritDoc
     */
    get enabled(): boolean;
    /**
     * @inheritDoc
     */
    onStateUpdate: EventEmitter<StateUpdateEvent>;
    protected _isPending: boolean;
    protected _pendingTransactions: T[];
    protected _pendingStates: Map<any, S>;
    private _cloneStrategy;
    /**
     * @inheritDoc
     */
    add(transaction: T, recordRef?: any): void;
    /**
     * @inheritDoc
     */
    getTransactionLog(_id?: any): T[];
    /**
     * @inheritDoc
     */
    undo(): void;
    /**
     * @inheritDoc
     */
    redo(): void;
    /**
     * @inheritDoc
     */
    getAggregatedChanges(mergeChanges: boolean): T[];
    /**
     * @inheritDoc
     */
    getState(id: any): S;
    /**
     * @inheritDoc
     */
    getAggregatedValue(id: any, mergeChanges: boolean): any;
    /**
     * @inheritDoc
     */
    commit(_data: any[], _id?: any): void;
    /**
     * @inheritDoc
     */
    clear(_id?: any): void;
    /**
     * @inheritDoc
     */
    startPending(): void;
    /**
     * @inheritDoc
     */
    endPending(_commit: boolean): void;
    /**
     * Updates the provided states collection according to passed transaction and recordRef
     *
     * @param states States collection to apply the update to
     * @param transaction Transaction to apply to the current state
     * @param recordRef Reference to the value of the record in data source, if any, where transaction should be applied
     */
    protected updateState(states: Map<any, S>, transaction: T, recordRef?: any): void;
    /**
     * Updates the recordRef of the provided state with all the changes in the state. Accepts primitive and object value types
     *
     * @param state State to update value for
     * @returns updated value including all the changes in provided state
     */
    protected updateValue(state: S): any;
    /**
     * Merges second values in first value and the result in empty object. If values are primitive type
     * returns second value if exists, or first value.
     *
     * @param first Value to merge into
     * @param second Value to merge
     */
    protected mergeValues<U>(first: U, second: U): U;
}
